package com.infinitegraph.samples.webgroup;
//Import InfiniteGraph packages
import com.infinitegraph.*;

// Import SLF4J logging packages
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


import java.net.URL;
// Import Calendar 
import java.util.Calendar;
import java.util.Scanner;

public class WebGroupSampleCreate {
	// Set up logging for the WebGroupSampleCreate class.
	static Logger logger = null;

	public static Logger getLogger() {
		if (logger == null)
			logger = LoggerFactory.getLogger(WebGroupSampleCreate.class);
		return logger;
	}

	public void createGraph() { 
		// Handle for the graph database instance
		GraphDatabase WebGroupSampleDB = null;

		// Names for the graph database and its properties file
		String graphDbName = "WebGroupSample";
		String propertiesFileName = "/config/Relations.properties";
		URL url= getClass().getResource(propertiesFileName);

		try 
		{
			try
			{
				// Delete graph database if it already exists.
				GraphFactory.delete(graphDbName, url.getPath());
			}
			catch (StorageException sE)
			{
				WebGroupSampleCreate.getLogger().info(sE.getMessage());
			}

			// Create the graph database instance.
			WebGroupSampleCreate.getLogger().info("> Creating graph database ...");
			GraphFactory.create(graphDbName, url.getPath());
			
			
			// HINT: Call to createGraphData method here.
			// Create the vertices, edges, and connect them.
			

			createGraphData(GraphFactory.open(graphDbName, url.getPath()));
		} 
		catch (ConfigurationException cE) 
		{
			WebGroupSampleCreate.getLogger().info("> CONFIGURATION EXCEPTION: " + cE.getMessage());
		} 
		catch (StorageException sE) 
		{
			WebGroupSampleCreate.getLogger().info("> STORAGE EXCEPTION: " + sE.getMessage());
		}

		finally {
			{
				try 
				{
					// Close the graph database.
					if (WebGroupSampleDB != null)
						WebGroupSampleDB.close();
				} 
				catch (StorageException sE) 
				{
					WebGroupSampleCreate.getLogger().info("> STORAGE EXCEPTION: " + sE.getMessage());
				}
			}
			WebGroupSampleCreate.getLogger().info("> Program completed ...");
		}
	}
	public static void createGraphData(GraphDatabase myGraph) {
	    WebGroupSampleCreate.getLogger().info("> Creating Data ...");

	    // Begin an update transaction.
	    Transaction tx = myGraph.beginTransaction(AccessMode.READ_WRITE);

	    // Delete objects from previous run.
	    myGraph.clear();

	    try {

	      // Create vertices and add them to the graph.
	      // Members
	      WebGroupSampleCreate.getLogger().info("> Creating vertices ...");
	      Person john = new Person("John", "1");
	      myGraph.addVertex(john);
	     	      
	      Calendar dateTime = Calendar.getInstance();
	      dateTime.set(2011, 4, 21, 9, 45, 22);
	      Status status1 = new Status("How are you?");
	      myGraph.addVertex(status1);
	     
	          
	     
	      

	      // Commit the changes to the graph database
	      tx.commit();
	      WebGroupSampleCreate.getLogger().info("> Committed changes ...");
	    } 
	    catch (Exception e) 
	    {
	      WebGroupSampleCreate.getLogger().info("> Exception in createGraphData: " + e.getMessage());
	      e.printStackTrace();
	      tx.rollback();
	    } 
	    finally 
	    {
	      tx.complete();
	      WebGroupSampleCreate.getLogger().info("> Finished completing transaction ...");
	    }
	  }
	
	

	
}
